@@ -27,6 +27,7 @@
 #define NDPI_CURRENT_PROTO NDPI_PROTOCOL_XDMCP
 
 #include "ndpi_api.h"
+#include "ndpi_private.h"
 
 
 static void ndpi_int_xdmcp_add_connection(struct ndpi_detection_module_struct
@@ -35,8 +36,8 @@ static void ndpi_int_xdmcp_add_connection(struct ndpi_detection_module_struct
   ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_XDMCP, NDPI_PROTOCOL_UNKNOWN, NDPI_CONFIDENCE_DPI);
 }
 
-void ndpi_search_xdmcp(struct ndpi_detection_module_struct
-		       *ndpi_struct, struct ndpi_flow_struct *flow)
+static void ndpi_search_xdmcp(struct ndpi_detection_module_struct *ndpi_struct,
+			      struct ndpi_flow_struct *flow)
 {
   struct ndpi_packet_struct *packet = &ndpi_struct->packet;
 	
@@ -64,9 +65,9 @@ void ndpi_search_xdmcp(struct ndpi_detection_module_struct
 }
 
 
-void init_xdmcp_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_int32_t *id, NDPI_PROTOCOL_BITMASK *detection_bitmask)
+void init_xdmcp_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_int32_t *id)
 {
-  ndpi_set_bitmask_protocol_detection("XDMCP", ndpi_struct, detection_bitmask, *id,
+  ndpi_set_bitmask_protocol_detection("XDMCP", ndpi_struct, *id,
 				      NDPI_PROTOCOL_XDMCP,
 				      ndpi_search_xdmcp,
 				      NDPI_SELECTION_BITMASK_PROTOCOL_V4_V6_TCP_OR_UDP_WITH_PAYLOAD_WITHOUT_RETRANSMISSION,
