@@ -257,13 +257,6 @@ bool ndFlow::HasTLSEncryptedCH(void) const {
       tls.ech.version != 0);
 }
 
-bool ndFlow::HasTLSEncryptedSNI(void) const {
-    return ((GetMasterProtocol() == ndProto::Id::TLS ||
-              detected_protocol == ndProto::Id::DTLS ||
-              detected_protocol == ndProto::Id::QUIC) &&
-      tls.esni.esni.empty() == false);
-}
-
 bool ndFlow::HasTLSServerCN(void) const {
     return ((GetMasterProtocol() == ndProto::Id::TLS ||
               detected_protocol == ndProto::Id::DTLS ||
@@ -634,15 +627,6 @@ void ndFlow::Print(ndFlags<PrintFlags> pflags,
                     << setfill(' ') << dec;
             }
 
-            if (HasTLSEncryptedSNI()) {
-                dls << endl
-                    << setw(plen) << " "
-                    << ": TLS/ESNI: 0x" << setfill('0')
-                    << setw(4) << hex
-                    << tls.esni.cipher_suite << setfill(' ')
-                    << dec << ": " << tls.esni.esni;
-            }
-
             if (HasTLSIssuerDN() || HasTLSSubjectDN()) {
                 dls << endl
                     << setw(plen) << " "
